"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Api_1 = __importDefault(require("./api/Api"));
const Config_1 = __importDefault(require("./Config"));
const Logger_1 = __importDefault(require("./Logger"));
const Report_1 = __importDefault(require("./report/Report"));
const Database_1 = __importDefault(require("./db/Database"));
const Service_1 = __importDefault(require("./service/Service"));
const BoltzClient_1 = __importDefault(require("./boltz/BoltzClient"));
const BackupScheduler_1 = __importDefault(require("./backup/BackupScheduler"));
const NotificationProvider_1 = __importDefault(require("./notifications/NotificationProvider"));
class BoltzMiddleware {
    constructor(argv) {
        this.start = () => __awaiter(this, void 0, void 0, function* () {
            yield Promise.all([
                this.db.init(),
                this.boltzClient.connect(),
            ]);
            yield Promise.all([
                this.service.init(this.config.pairs),
                this.notifications.init(),
            ]);
            yield this.api.init();
        });
        this.config = new Config_1.default();
        this.config.init(argv);
        this.logger = new Logger_1.default(this.config.logpath, this.config.loglevel);
        this.db = new Database_1.default(this.logger, this.config.dbpath);
        this.boltzClient = new BoltzClient_1.default(this.logger, this.config.boltz);
        this.service = new Service_1.default(this.logger, this.boltzClient, this.config.api.interval, this.config.currencies);
        this.backup = new BackupScheduler_1.default(this.logger, this.config.dbpath, this.config.backup, this.boltzClient, new Report_1.default(this.service.swapRepository, this.service.reverseSwapRepository));
        this.notifications = new NotificationProvider_1.default(this.logger, this.service, this.boltzClient, this.backup, this.config.notification, this.config.currencies);
        this.api = new Api_1.default(this.logger, this.config.api, this.service);
    }
}
exports.default = BoltzMiddleware;
//# sourceMappingURL=BoltzMiddleware.js.map