"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = __importDefault(require("winston"));
const safe_1 = __importDefault(require("colors/safe"));
class Logger {
    constructor(filename, level, disabled = false) {
        this.disabled = disabled;
        this.getLogFormat = (colorize) => {
            return winston_1.default.format.printf(info => `${this.getTsString()} ${this.getLevel(info.level, colorize)}: ${info.message}`);
        };
        this.getLevel = (level, colorize) => {
            if (colorize) {
                switch (level) {
                    case 'error': return safe_1.default.red(level);
                    case 'warn': return safe_1.default.yellow(level);
                    case 'info': return safe_1.default.green(level);
                    case 'verbose': return safe_1.default.cyan(level);
                    case 'debug': return safe_1.default.blue(level);
                    case 'silly': return safe_1.default.magenta(level);
                }
            }
            return level;
        };
        this.error = (message) => {
            this.log('error', message);
        };
        this.warn = (message) => {
            this.log('warn', message);
        };
        this.info = (message) => {
            this.log('info', message);
        };
        this.verbose = (message) => {
            this.log('verbose', message);
        };
        this.debug = (message) => {
            this.log('debug', message);
        };
        this.silly = (message) => {
            this.log('silly', message);
        };
        this.log = (level, message) => {
            if (!this.disabled) {
                winston_1.default.log(level, message);
            }
        };
        this.getTsString = () => (new Date()).toLocaleString('en-US', { hour12: false });
        if (disabled) {
            return;
        }
        winston_1.default.configure({
            level,
            transports: [
                new winston_1.default.transports.Console({
                    format: this.getLogFormat(true),
                }),
                new winston_1.default.transports.File({
                    filename,
                    format: this.getLogFormat(false),
                }),
            ],
        });
    }
}
Logger.disabledLogger = new Logger('', '', true);
exports.default = Logger;
//# sourceMappingURL=Logger.js.map