"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cors_1 = __importDefault(require("cors"));
const express_1 = __importDefault(require("express"));
const Controller_1 = __importDefault(require("./Controller"));
class Api {
    constructor(logger, config, service) {
        this.logger = logger;
        this.config = config;
        this.init = () => __awaiter(this, void 0, void 0, function* () {
            yield this.controller.init();
            this.app.listen(this.config.port, this.config.host, () => {
                this.logger.info(`API server listening on: ${this.config.host}:${this.config.port}`);
            });
        });
        this.registerRoutes = (controller) => {
            // GET requests
            this.app.route('/getpairs').get(controller.getPairs);
            this.app.route('/getfeeestimation').get(controller.getFeeEstimation);
            // POST requests
            this.app.route('/swapstatus').post(controller.swapStatus);
            this.app.route('/gettransaction').post(controller.getTransaction);
            this.app.route('/broadcasttransaction').post(controller.broadcastTransaction);
            this.app.route('/createswap').post(controller.createSwap);
            this.app.route('/createreverseswap').post(controller.createReverseSwap);
            // EventSource streams
            this.app.route('/streamswapstatus').get(controller.streamSwapStatus);
        };
        this.app = express_1.default();
        this.controller = new Controller_1.default(logger, service);
        this.app.use(cors_1.default());
        this.app.use(express_1.default.json());
        // Catch the ugly errors generated by the body-parser
        this.app.use((error, _req, res, next) => {
            if (error instanceof SyntaxError) {
                this.controller.errorResponse(res, error);
                return;
            }
            next();
        });
        this.registerRoutes(this.controller);
    }
}
exports.default = Api;
//# sourceMappingURL=Api.js.map