"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sequelize_1 = require("sequelize");
const Pair_1 = __importDefault(require("./models/Pair"));
const Swap_1 = __importDefault(require("./models/Swap"));
const ReverseSwap_1 = __importDefault(require("./models/ReverseSwap"));
class Database {
    /**
     * @param storage the file path to the SQLite databse; if ':memory:' the databse will be stored in the memory
     */
    constructor(logger, storage) {
        this.logger = logger;
        this.storage = storage;
        this.init = () => __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.sequelize.authenticate();
                this.logger.info(`Connected to database: ${this.storage === ':memory:' ? 'in memory' : this.storage}`);
            }
            catch (error) {
                this.logger.error(`Could not connect to database: ${error}`);
                throw error;
            }
            yield Pair_1.default.sync(),
                yield Promise.all([
                    Swap_1.default.sync(),
                    ReverseSwap_1.default.sync(),
                ]);
        });
        this.close = () => __awaiter(this, void 0, void 0, function* () {
            yield this.sequelize.close();
        });
        this.loadModels = () => {
            Pair_1.default.load(this.sequelize);
            Swap_1.default.load(this.sequelize);
            ReverseSwap_1.default.load(this.sequelize);
        };
        this.sequelize = new sequelize_1.Sequelize({
            storage,
            dialect: 'sqlite',
            logging: this.logger.silly,
        });
        this.loadModels();
    }
}
exports.default = Database;
//# sourceMappingURL=Database.js.map