"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const Errors_1 = __importDefault(require("./Errors"));
class CryptoCompare {
    constructor() {
        this.getPriceMulti = (fromSymbols, toSymbols) => {
            return this.makeRequest(`data/pricemulti?fsyms=${this.arrayToList(fromSymbols)}&tsyms=${this.arrayToList(toSymbols)}`);
        };
        this.makeRequest = (endpoint) => __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield axios_1.default.get(`${CryptoCompare.URL}/${endpoint}`);
                // CryptoCompare is always returning the status code 200 therefore the response data
                // has to be parsed to determine whether the request was successful
                if (response.data.Response === 'Error') {
                    throw Errors_1.default.COULD_NOT_GET_RATE(response.data.Message);
                }
                return response.data;
            }
            catch (error) {
                // If "error.code" is defined it is an error from axios which means that is has to be parsed first
                if (!error.code) {
                    throw Errors_1.default.COULD_NOT_GET_RATE(error.code);
                }
                throw error;
            }
        });
        /**
         * Turns an array of strings into a comma separated list
         */
        this.arrayToList = (array) => {
            return array.join(',');
        };
    }
}
CryptoCompare.URL = 'https://min-api.cryptocompare.com';
exports.default = CryptoCompare;
//# sourceMappingURL=CryptoCompare.js.map