"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Utils_1 = require("../Utils");
class FeeProvider {
    constructor(logger, boltz) {
        this.logger = logger;
        this.boltz = boltz;
        // A map between the symbols of the pairs and their percentage fees
        this.percentageFees = new Map();
        this.init = (pairs) => {
            pairs.forEach((pair) => {
                // Set the configured fee or fallback to 1% if it is not defined
                const percentage = pair.fee !== undefined ? pair.fee : 1;
                this.percentageFees.set(Utils_1.getPairId(pair), percentage / 100);
            });
            this.logger.debug(`Prepared data for fee estimations: ${Utils_1.stringify(Utils_1.mapToObject(this.percentageFees))}`);
        };
        this.getFee = (pair, chainCurrency, amount, isReverse) => __awaiter(this, void 0, void 0, function* () {
            const feeReponse = yield this.boltz.getFeeEstimation(chainCurrency);
            const feeMap = Utils_1.feeMapToObject(feeReponse.feesMap);
            const baseFee = this.getBaseFee(feeMap[chainCurrency], isReverse);
            // Multiply the amount with the percentage fee or with 0 if there is no percentage fee for that pair
            const percentageFee = Math.ceil((this.percentageFees.get(pair) || 0) * amount);
            return {
                baseFee,
                percentageFee,
            };
        });
        this.getBaseFee = (satPerVbyte, isReverse) => {
            if (isReverse) {
                // The lockup transaction which spends a P2WPKH output (possibly more but we assume a best case scenario here),
                // locks up funds in a P2WSH swap and sends the change back to a P2WKH output has about 153 vbytes
                return satPerVbyte * FeeProvider.transactionSizes.reverseLockup;
            }
            else {
                // The claim transaction which spends a nested SegWit swap output and
                // sends it to a P2WPKH address has about 140 vbytes
                return satPerVbyte * FeeProvider.transactionSizes.normalClaim;
            }
        };
    }
}
FeeProvider.transactionSizes = {
    normalClaim: 140,
    reverseLockup: 153,
    reverseClaim: 138,
};
exports.default = FeeProvider;
//# sourceMappingURL=FeeProvider.js.map